@@ -29,6 +29,10 @@ class Model():
         for i in class_dict_more.items():
             if  i[1][0]  == 'datetime_property' and i[1][1]['auto_now']:self.datetime_property.append((i[0],class_dict_more[i[0]]))
 
+        self.dict_property = [] #self.dict_property 
+        for i in class_dict_more.items():
+            if  i[1][0]  == 'dict_property' and i[1][1]['auto_add']:self.dict_property.append((i[0],class_dict_more[i[0]]))
+
         arg_1 = arg.copy()
         for i in class_dict_more.items():
             arg_1[i[0]] = ModelFilter(arg[i[0]],i[1]) if arg_1.has_key(i[0]) else i[1][2]
@@ -226,6 +230,9 @@ class Model():
         else:
             for i in self.datetime_property:
                     new_value[i[0]] = data_old[0][i[0]]
+            for i in self.dict_property:
+                    new_value[i[0]].update(data_old[0][i[0]])
+        
         
         data = self.db_name_table_name.update({name:value},{"$set":new_value})
         return data#返回ture 布尔值
@@ -250,6 +257,8 @@ class Model():
         else:
             for i in self.datetime_property:
                     new_value[i[0]] = data_old[i[0]]
+            for i in self.dict_property:
+                    new_value[i[0]].update(data_old[0][i[0]])
 
         data = self.db_name_table_name.update({"_id":ObjectId(value)},{"$set":new_value})
         return data#返回ture 布尔值
@@ -287,6 +296,8 @@ class ModelFilter(object):#有长度
             return value #过滤是否合格的dict格式
         if v2[0] == 'email_property':
             return value #过滤是否合格的dict格式
+        if v2[0] == 'list_property':
+            return value #过滤是否合格的dict格式
 
 #首先是外属性，然后是内属性，再是默认值，再是附加值
 class StringProperty(object):
@@ -360,6 +371,17 @@ class DictProperty(object):
         dict_property_dict = {}
         return [me,dict_property_dict,default,{}]
 
+class ListProperty(object):
+    def __new__(cls,**arg):
+        list_property_arg = arg
+        me = 'list_property'
+
+        default_io = list_property_arg.has_key('default')
+        default = list_property_arg['default'] if default_io else []
+        
+        list_property_dict = {}
+        return [me,list_property_dict,default,{}]
+
 class EmailProperty(object):
     def __new__(cls,**arg):
         email_property_arg = arg
